==> dballe_8.3.orig.tar.gz: dballe-8.3/dballe/core/aliases.cc <==
/* C++ code produced by gperf version 3.1 */
/* Command-line: gperf  */
/* Computed positions: -k'$' */

#if !((' ' == 32) && ('!' == 33) && ('"' == 34) && ('#' == 35) \
      && ('%' == 37) && ('&' == 38) && ('\'' == 39) && ('(' == 40) \
      && (')' == 41) && ('*' == 42) && ('+' == 43) && (',' == 44) \
      && ('-' == 45) && ('.' == 46) && ('/' == 47) && ('0' == 48) \
      && ('1' == 49) && ('2' == 50) && ('3' == 51) && ('4' == 52) \
      && ('5' == 53) && ('6' == 54) && ('7' == 55) && ('8' == 56) \
      && ('9' == 57) && (':' == 58) && (';' == 59) && ('<' == 60) \
      && ('=' == 61) && ('>' == 62) && ('?' == 63) && ('A' == 65) \
      && ('B' == 66) && ('C' == 67) && ('D' == 68) && ('E' == 69) \
      && ('F' == 70) && ('G' == 71) && ('H' == 72) && ('I' == 73) \
      && ('J' == 74) && ('K' == 75) && ('L' == 76) && ('M' == 77) \
      && ('N' == 78) && ('O' == 79) && ('P' == 80) && ('Q' == 81) \
      && ('R' == 82) && ('S' == 83) && ('T' == 84) && ('U' == 85) \
      && ('V' == 86) && ('W' == 87) && ('X' == 88) && ('Y' == 89) \
      && ('Z' == 90) && ('[' == 91) && ('\\' == 92) && (']' == 93) \
      && ('^' == 94) && ('_' == 95) && ('a' == 97) && ('b' == 98) \
      && ('c' == 99) && ('d' == 100) && ('e' == 101) && ('f' == 102) \
      && ('g' == 103) && ('h' == 104) && ('i' == 105) && ('j' == 106) \
      && ('k' == 107) && ('l' == 108) && ('m' == 109) && ('n' == 110) \
      && ('o' == 111) && ('p' == 112) && ('q' == 113) && ('r' == 114) \
      && ('s' == 115) && ('t' == 116) && ('u' == 117) && ('v' == 118) \
      && ('w' == 119) && ('x' == 120) && ('y' == 121) && ('z' == 122) \
      && ('{' == 123) && ('|' == 124) && ('}' == 125) && ('~' == 126))
/* The character set is not based on ISO-646.  */
#error "gperf generated tables don't work with this execution character set. Please report a bug to <bug-gperf@gnu.org>."
#endif


#include <string.h>
#include <wreport/varinfo.h>

using namespace wreport;

namespace dballe {
struct aliasdef { const char* alias; Varcode var; };

#define TOTAL_KEYWORDS 27
#define MIN_WORD_LENGTH 1
#define MAX_WORD_LENGTH 10
#define MIN_HASH_VALUE 1
#define MAX_HASH_VALUE 34
/* maximum key range = 34, duplicates = 0 */

class VarcodeAliases
{
private:
  static inline unsigned int hash (const char *str, size_t len);
public:
  static struct aliasdef *find (const char *str, size_t len);
};

inline unsigned int
VarcodeAliases::hash (const char *str, size_t len)
{
  static unsigned char asso_values[] =
    {
      35, 35, 35, 35, 35, 35, 35, 35, 35, 35,
      35, 35, 35, 35, 35, 35, 35, 35, 35, 35,
      35, 35, 35, 35, 35, 35, 35, 35, 35, 35,
      35, 35, 35, 35, 35, 35, 35, 35, 35, 35,
      35, 35, 35, 35, 35, 35, 35, 35, 30, 35,
      10, 30, 35, 35, 35, 35, 35, 35, 35, 35,
      35, 35, 35, 35, 35, 35, 35, 35, 35, 35,
      35, 35, 35, 35, 35, 35, 35, 35, 35, 35,
      35, 35, 35, 35, 35, 35, 35, 35, 35, 35,
      35, 35, 35, 35, 35, 35, 35, 35, 35, 35,
       5, 25, 20, 35, 25, 35, 35,  0, 35, 35,
      15, 15,  0, 30, 35, 35,  5, 25, 20, 35,
      10, 35, 15, 35, 35, 35, 35, 35, 35, 35,
      35, 35, 35, 35, 35, 35, 35, 35, 35, 35,
      35, 35, 35, 35, 35, 35, 35, 35, 35, 35,
      35, 35, 35, 35, 35, 35, 35, 35, 35, 35,
      35, 35, 35, 35, 35, 35, 35, 35, 35, 35,
      35, 35, 35, 35, 35, 35, 35, 35, 35, 35,
      35, 35, 35, 35, 35, 35, 35, 35, 35, 35,
      35, 35, 35, 35, 35, 35, 35, 35, 35, 35,
      35, 35, 35, 35, 35, 35, 35, 35, 35, 35,
      35, 35, 35, 35, 35, 35, 35, 35, 35, 35,
      35, 35, 35, 35, 35, 35, 35, 35, 35, 35,
      35, 35, 35, 35, 35, 35, 35, 35, 35, 35,
      35, 35, 35, 35, 35, 35, 35, 35, 35, 35,
      35, 35, 35, 35, 35, 35
    };
  return len + asso_values[static_cast<unsigned char>(str[len - 1])];
}

static struct aliasdef wordlist[] =
  {
    {""},
    {"p",			WR_VAR(0, 10,   4)},
    {"tp",			WR_VAR(0, 13,  11)},
    {"mwp",			WR_VAR(0, 22,  74)},
    {"mslp",			WR_VAR(0, 10,  51)},
    {"block",			WR_VAR(0,  1,   1)},
    {"t",			WR_VAR(0, 12, 101)},
    {"td",			WR_VAR(0, 12, 103)},
    {"mwd",			WR_VAR(0, 22,   1)},
    {"pp1d",			WR_VAR(0, 22,  71)},
    {""},
    {"height",			WR_VAR(0,  7,  30)},
    {"data_id",		WR_VAR(0, 33, 195)},
    {"no2",			WR_VAR(0, 15, 193)},
    {"tmax",			WR_VAR(0, 12,  11)},
    {""},
    {"z",			WR_VAR(0, 10,   3)},
    {"no",			WR_VAR(0, 15, 192)},
    {""},
    {"tmin",			WR_VAR(0, 12,  12)},
    {""},
    {"v",			WR_VAR(0, 11,   4)},
    {"station",		WR_VAR(0,  1,   2)},
    {""},
    {"conf",			WR_VAR(0, 33,   7)},
    {"heightbaro",		WR_VAR(0,  7,  31)},
    {"u",			WR_VAR(0, 11,   3)},
    {"rh",			WR_VAR(0, 13,   3)},
    {"swh",			WR_VAR(0, 22,  70)},
    {"name",			WR_VAR(0,  1,  19)},
    {""},
    {"q",			WR_VAR(0, 13,   1)},
    {"o3",			WR_VAR(0, 15, 194)},
    {""},
    {"pm10",			WR_VAR(0, 15, 195)}
  };

struct aliasdef *
VarcodeAliases::find (const char *str, size_t len)
{
  if (len <= MAX_WORD_LENGTH && len >= MIN_WORD_LENGTH)
    {
      unsigned int key = hash (str, len);

      if (key <= MAX_HASH_VALUE)
        {
          const char *s = wordlist[key].alias;

          if (*str == *s && !strncmp (str + 1, s + 1, len - 1) && s[len] == '\0')
            return &wordlist[key];
        }
    }
  return 0;
}


Varcode varcode_alias_resolve(const char* alias)
{
	struct aliasdef* res = VarcodeAliases::find(alias, strlen(alias));
	if (res == NULL)
		return 0;
	else
		return res->var;
}

Varcode varcode_alias_resolve_substring(const char* alias, int len)
{
	struct aliasdef* res = VarcodeAliases::find(alias, len);
	if (res == NULL)
		return 0;
	else
		return res->var;
}

wreport::Varcode varcode_alias_resolve(const std::string& alias)
{
	struct aliasdef* res = VarcodeAliases::find(alias.data(), alias.size());
	if (res == NULL)
		return 0;
	else
		return res->var;
}

}

/* vim:set ts=4 sw=4: */

==> dballe_8.6.orig.tar.gz: dballe-8.6/dballe/core/aliases.cc <==
/* C++ code produced by gperf version 3.1 */
/* Command-line: gperf  */
/* Computed positions: -k'$' */

#if !((' ' == 32) && ('!' == 33) && ('"' == 34) && ('#' == 35) \
      && ('%' == 37) && ('&' == 38) && ('\'' == 39) && ('(' == 40) \
      && (')' == 41) && ('*' == 42) && ('+' == 43) && (',' == 44) \
      && ('-' == 45) && ('.' == 46) && ('/' == 47) && ('0' == 48) \
      && ('1' == 49) && ('2' == 50) && ('3' == 51) && ('4' == 52) \
      && ('5' == 53) && ('6' == 54) && ('7' == 55) && ('8' == 56) \
      && ('9' == 57) && (':' == 58) && (';' == 59) && ('<' == 60) \
      && ('=' == 61) && ('>' == 62) && ('?' == 63) && ('A' == 65) \
      && ('B' == 66) && ('C' == 67) && ('D' == 68) && ('E' == 69) \
      && ('F' == 70) && ('G' == 71) && ('H' == 72) && ('I' == 73) \
      && ('J' == 74) && ('K' == 75) && ('L' == 76) && ('M' == 77) \
      && ('N' == 78) && ('O' == 79) && ('P' == 80) && ('Q' == 81) \
      && ('R' == 82) && ('S' == 83) && ('T' == 84) && ('U' == 85) \
      && ('V' == 86) && ('W' == 87) && ('X' == 88) && ('Y' == 89) \
      && ('Z' == 90) && ('[' == 91) && ('\\' == 92) && (']' == 93) \
      && ('^' == 94) && ('_' == 95) && ('a' == 97) && ('b' == 98) \
      && ('c' == 99) && ('d' == 100) && ('e' == 101) && ('f' == 102) \
      && ('g' == 103) && ('h' == 104) && ('i' == 105) && ('j' == 106) \
      && ('k' == 107) && ('l' == 108) && ('m' == 109) && ('n' == 110) \
      && ('o' == 111) && ('p' == 112) && ('q' == 113) && ('r' == 114) \
      && ('s' == 115) && ('t' == 116) && ('u' == 117) && ('v' == 118) \
      && ('w' == 119) && ('x' == 120) && ('y' == 121) && ('z' == 122) \
      && ('{' == 123) && ('|' == 124) && ('}' == 125) && ('~' == 126))
/* The character set is not based on ISO-646.  */
#error "gperf generated tables don't work with this execution character set. Please report a bug to <bug-gperf@gnu.org>."
#endif


#include <string.h>
#include <wreport/varinfo.h>

using namespace wreport;

namespace dballe {
struct aliasdef { const char* alias; Varcode var; };

#define TOTAL_KEYWORDS 24
#define MIN_WORD_LENGTH 1
#define MAX_WORD_LENGTH 10
#define MIN_HASH_VALUE 1
#define MAX_HASH_VALUE 32
/* maximum key range = 32, duplicates = 0 */

class VarcodeAliases
{
private:
  static inline unsigned int hash (const char *str, size_t len);
public:
  static struct aliasdef *find (const char *str, size_t len);
};

inline unsigned int
VarcodeAliases::hash (const char *str, size_t len)
{
  static unsigned char asso_values[] =
    {
      33, 33, 33, 33, 33, 33, 33, 33, 33, 33,
      33, 33, 33, 33, 33, 33, 33, 33, 33, 33,
      33, 33, 33, 33, 33, 33, 33, 33, 33, 33,
      33, 33, 33, 33, 33, 33, 33, 33, 33, 33,
      33, 33, 33, 33, 33, 33, 33, 33, 20, 33,
      10, 30, 33, 33, 33, 33, 33, 33, 33, 33,
      33, 33, 33, 33, 33, 33, 33, 33, 33, 33,
      33, 33, 33, 33, 33, 33, 33, 33, 33, 33,
      33, 33, 33, 33, 33, 33, 33, 33, 33, 33,
      33, 33, 33, 33, 33, 33, 33, 33, 33, 33,
       5, 15, 10, 33, 20, 33, 33,  0, 33, 33,
      20, 15,  0, 25, 33, 33,  5, 20, 15, 33,
      33, 33, 33, 33, 33, 33, 33, 33, 33, 33,
      33, 33, 33, 33, 33, 33, 33, 33, 33, 33,
      33, 33, 33, 33, 33, 33, 33, 33, 33, 33,
      33, 33, 33, 33, 33, 33, 33, 33, 33, 33,
      33, 33, 33, 33, 33, 33, 33, 33, 33, 33,
      33, 33, 33, 33, 33, 33, 33, 33, 33, 33,
      33, 33, 33, 33, 33, 33, 33, 33, 33, 33,
      33, 33, 33, 33, 33, 33, 33, 33, 33, 33,
      33, 33, 33, 33, 33, 33, 33, 33, 33, 33,
      33, 33, 33, 33, 33, 33, 33, 33, 33, 33,
      33, 33, 33, 33, 33, 33, 33, 33, 33, 33,
      33, 33, 33, 33, 33, 33, 33, 33, 33, 33,
      33, 33, 33, 33, 33, 33, 33, 33, 33, 33,
      33, 33, 33, 33, 33, 33
    };
  return len + asso_values[static_cast<unsigned char>(str[len - 1])];
}

static struct aliasdef wordlist[] =
  {
    {""},
    {"p",			WR_VAR(0, 10,   4)},
    {"tp",			WR_VAR(0, 13,  11)},
    {"mwp",			WR_VAR(0, 22,  74)},
    {"mslp",			WR_VAR(0, 10,  51)},
    {"block",			WR_VAR(0,  1,   1)},
    {"t",			WR_VAR(0, 12, 101)},
    {"td",			WR_VAR(0, 12, 103)},
    {"mwd",			WR_VAR(0, 22,   1)},
    {"pp1d",			WR_VAR(0, 22,  71)},
    {""},
    {"height",			WR_VAR(0,  7,  30)},
    {"data_id",		WR_VAR(0, 33, 195)},
    {"no2",			WR_VAR(0, 15, 193)},
    {"conf",			WR_VAR(0, 33,   7)},
    {""},
    {"v",			WR_VAR(0, 11,   4)},
    {"no",			WR_VAR(0, 15, 192)},
    {""},
    {"name",			WR_VAR(0,  1,  19)},
    {""},
    {"u",			WR_VAR(0, 11,   3)},
    {"rh",			WR_VAR(0, 13,   3)},
    {"swh",			WR_VAR(0, 22,  70)},
    {"pm10",			WR_VAR(0, 15, 195)},
    {"heightbaro",		WR_VAR(0,  7,  31)},
    {"q",			WR_VAR(0, 13,   1)},
    {"station",		WR_VAR(0,  1,   2)},
    {""}, {""}, {""}, {""},
    {"o3",			WR_VAR(0, 15, 194)}
  };

struct aliasdef *
VarcodeAliases::find (const char *str, size_t len)
{
  if (len <= MAX_WORD_LENGTH && len >= MIN_WORD_LENGTH)
    {
      unsigned int key = hash (str, len);

      if (key <= MAX_HASH_VALUE)
        {
          const char *s = wordlist[key].alias;

          if (*str == *s && !strncmp (str + 1, s + 1, len - 1) && s[len] == '\0')
            return &wordlist[key];
        }
    }
  return 0;
}


Varcode varcode_alias_resolve(const char* alias)
{
	struct aliasdef* res = VarcodeAliases::find(alias, strlen(alias));
	if (res == NULL)
		return 0;
	else
		return res->var;
}

Varcode varcode_alias_resolve_substring(const char* alias, int len)
{
	struct aliasdef* res = VarcodeAliases::find(alias, len);
	if (res == NULL)
		return 0;
	else
		return res->var;
}

wreport::Varcode varcode_alias_resolve(const std::string& alias)
{
	struct aliasdef* res = VarcodeAliases::find(alias.data(), alias.size());
	if (res == NULL)
		return 0;
	else
		return res->var;
}

}

/* vim:set ts=4 sw=4: */
